@@ -26,8 +26,8 @@
 #include "driveservice.h"
 #include "utils.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
+#include <QNetworkRequest>
+#include <QNetworkReply>
 
 
 using namespace KGAPI2;
@@ -88,7 +88,7 @@ ChildReferenceCreateJob::ChildReferenceCreateJob(const QString &folderId,
     d(new Private(this))
 {
     d->folderId = folderId;
-    Q_FOREACH(const QString & childId, childrenIds) {
+    for (const QString & childId : qAsConst(childrenIds)) {
         d->references << ChildReferencePtr(new ChildReference(childId));
     }
 }
